@@ -158,9 +158,23 @@ def _harmalysis_special(special, key_function=None, tonicizations=[]):
      degree = special.scale_degree
      degree_alteration = special.scale_degree_alteration
      if harmalysis.secondary_key:
+          if type(special) == CadentialSixFourChord:
+               if harmalysis.secondary_key.scale == 'major':
+                    special.set_as_major()
+               else:
+                    special.set_as_minor()
+               degree = special.scale_degree
           special.root = harmalysis.secondary_key.scale_degree(degree, degree_alteration)
+
      else:
+          if type(special) == CadentialSixFourChord:
+               if harmalysis.main_key.scale == 'major':
+                    special.set_as_major()
+               else:
+                    special.set_as_minor()
+               degree = special.scale_degree
           special.root = harmalysis.main_key.scale_degree(degree, degree_alteration)
+
      harmalysis.chord = special
      return harmalysis
 
@@ -296,7 +310,9 @@ class RomanParser(Transformer):
      ## Parsing tonicizations
      ########################
      by_scale_degree_major = lambda self, degree: (None, str(degree).lower(), "major")
+     by_scale_degree_major_with_alteration = lambda self, alteration, degree: (str(alteration), str(degree), "major")
      by_scale_degree_minor = lambda self, degree: (None, str(degree), "default_minor")
+     by_scale_degree_minor_with_alteration = lambda self, alteration, degree: (str(alteration), str(degree), "default_minor")
      by_scale_degree_neapolitan = lambda self, degree: ('b', "ii", "major")
      tonicization = lambda self, *args: list(args)
      #############################
